! This programs sets the initial conditions for the Fermi-Pasta-Ulam problem,
! so that the energy is completely contained in the first normal mode

PROGRAM ic
IMPLICIT NONE

REAL(KIND=8), PARAMETER::pi=acos(-1.d0)
INTEGER(KIND=8)::N ! number of particles
REAL(KIND=8), DIMENSION(:), ALLOCATABLE:: x, v ! coordinates and velocities
REAL(KIND=8):: A ! oscillation amplitude
INTEGER(KIND=8)::i ! indexes

! read number of particles and allocate vectors
PRINT *, 'Reading grid parameters...'
OPEN(UNIT=1, FILE='input/input_data.dat')
READ (1, *)
READ (1, *) N
READ (1, *)
READ (1, *) A
CLOSE(UNIT=1)

PRINT *, 'Allocating vectors...'
ALLOCATE (x(0:N-1), v(0:N-1))


! assign initial conditions
PRINT *, 'Setting initial conditions...'
DO i=0, N-1
  x(i)=A*sin(2.d0*pi*dble(i)/dble(N))
ENDDO
v=0

! output
PRINT *, 'Producing output...'
OPEN(UNIT=1, FILE='input/ic.dat')
DO i=0, N-1
  WRITE(1, *) i, x(i), v(i)
END DO
CLOSE(UNIT=1)

ENDPROGRAM
